#' \code{swfscMisc} package
#'
#' SWFSC Miscellaneous Functions
#' 
#' @aliases swfscMisc-package
#' @name swfscMisc
#' @importFrom rlang .data
"_PACKAGE"

## quiets concerns of R CMD check re: the .'s that appear in pipelines
##if(getRversion() >= "2.15.1")  utils::globalVariables(c("."))
